@@ -26,8 +26,12 @@ class KeyboardMonitor:
             handler.handle(key)
 
 
+global _KEYBOARD_LISTENER_STARTED
 _KEYBOARD_LISTENER_STARTED = False
 
+global _KEYBOARD_LISTENER
+_KEYBOARD_LISTENER = None
+
 
 def keyboard_listener_start():
     global _KEYBOARD_LISTENER_STARTED
@@ -37,4 +41,7 @@ def keyboard_listener_start():
     listener = KeyboardListener(on=KeyboardMonitor.on)
     listener.start()
 
+    global _KEYBOARD_LISTENER
+    _KEYBOARD_LISTENER = listener
+
     _KEYBOARD_LISTENER_STARTED = True
